@@ -199,8 +199,8 @@ class CresWidget(QMainWindow):
             spinbox.setRange(1, 10)
             layout_we.addWidget(spinbox, len(unique_classes), 1)
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _shade_browse(self, path):
         """ When the users browses for a shade spectrum, set the reflectance scale factor.
@@ -220,8 +220,8 @@ class CresWidget(QMainWindow):
             # set the shade reflectance scale factor
             self.shadeScaleValue.setValue(detect_reflectance_scale_factor(self.shade))
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
             self.shade = None
             self.browseShade.setFilePath('')
 
@@ -235,8 +235,8 @@ class CresWidget(QMainWindow):
             if target_fractions != 0:
                 self.shade_spinbox.setValue(100 - target_fractions)
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _calculate_sma(self):
         """ Read all parameters and run CRES. """
@@ -270,8 +270,8 @@ class CresWidget(QMainWindow):
             self.table_model.resetRows(self.cres_object.get_fractions(), self.spectrum_names_per_class)
             self.nModelsShown.setText("# models shown: " + str(self.table_model.rowCount()))
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _calculate_index(self):
         try:
@@ -292,21 +292,21 @@ class CresWidget(QMainWindow):
                                              weight_rmse=weights[-1])
             self.table_model.addColumns(indices)
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _update(self):
         try:
             self.tableView.update()
             self.nModelsSelected.setText("# models selected: " + str(self.table_model.number_selected()))
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _set_filter_rmse(self, checked: bool = False):
         try:
             self._filter_rmse(value=self.filterRMSEValue.value()) if checked else self._filter_rmse()
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _filter_rmse(self, value: float = None):
         try:
@@ -317,14 +317,14 @@ class CresWidget(QMainWindow):
                                                                  table_model.columnCount() - 1))
             self.nModelsShown.setText("# models shown: " + str(self.filter_model.rowCount()))
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _set_filter_min_frac(self, checked: bool = False):
         try:
             self._filter_min_frac(value=self.filterMinFracValue.value()) if checked else self._filter_min_frac()
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _filter_min_frac(self, value: float = None):
         try:
@@ -336,14 +336,14 @@ class CresWidget(QMainWindow):
 
             self.nModelsShown.setText("# models shown: " + str(self.filter_model.rowCount()))
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _set_filter_max_frac(self, checked: bool = False):
         try:
             self._filter_max_frac(value=self.filterMaxFracValue.value()) if checked else self._filter_max_frac()
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _filter_max_frac(self, value: float = None):
         try:
@@ -354,8 +354,8 @@ class CresWidget(QMainWindow):
                                                                  table_model.columnCount() - 1))
             self.nModelsShown.setText("# models shown: " + str(self.filter_model.rowCount()))
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
     def _export(self):
         try:
@@ -384,8 +384,8 @@ class CresWidget(QMainWindow):
             cres_library = self.spectral_library_object.speclibFromFeatureIDs(fid_list)
             cres_library.exportProfiles(path=output_path)
 
-        except Exception:
-            self.log(Exception)
+        except Exception as e:
+            self.log(e)
 
 
 class CresTableModel(QAbstractTableModel):
